/**
   class Logfile

   Copyright (C) 2002-4 Sebastian Pado
   
   This file is part of the DependencyVectors v2 distribution.
   
   DependencyVectors is free software; you can redistribute it
   and/or modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later
   version.
   
   DependencyVectors is distributed in the hope that it will be
   useful, but WITHOUT ANY WARRANTY; without even the implied
   warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
   PURPOSE.  See the GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public
   License along with DependencyVectors; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
   MA 02111-1307 USA

**/

package de.ims.cl.dv.util;

import java.util.*;
import java.io.*;

/** This class creates a logfile to which program output can be
    sent, such as warnings, errors and status messages.
**/

public class Logfile {
  
  FileWriter logfile;

    /** Writes a string to the logfile 
     **/
    public void println(String s) throws IOException {
	s = getTime() + ": "+s+"\n"; // prefix date
	logfile.write(s,0,s.length());
	logfile.flush();
    }

  
  /** Closes logfile. This method must be called at the end of the
      program to force emptying the buffer into the file.
  **/
    public void close() throws IOException{
	    this.println("Closing logfile.");
	    logfile.close();
    } 

    private String getTime() { // get time from system libraries
	Calendar cal = Calendar.getInstance(TimeZone.getDefault());
	String DATE_FORMAT = "yyyy-MM-dd HH:mm:ss";
	java.text.SimpleDateFormat sdf = new java.text.SimpleDateFormat(DATE_FORMAT);
	sdf.setTimeZone(TimeZone.getDefault());               
	return sdf.format(cal.getTime());
    }
    
    /** Opens a new logfile at the position filename.
     **/

    public Logfile(String filename) throws IOException {
	    logfile = new FileWriter(filename);
	    this.println("Opening logfile.");	    
    }
}

